==> haskell-sourcemap-0.1.6-94-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-sourcemap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: sourcemap
version: 0.1.6
id: sourcemap-0.1.6-51NpicaMDzE9fQzweNey22
key: sourcemap-0.1.6-51NpicaMDzE9fQzweNey22
license: BSD-3-Clause
copyright: 2012 Chris Done
maintainer: chrisdone@gmail.com
author: Chris Done
stability: alpha
synopsis: Implementation of source maps as proposed by Google and Mozilla.
description:
    Implementation of source maps, revision 3, proposed by Google and Mozilla here
    <https://wiki.mozilla.org/DevTools/Features/SourceMap> and here
    <https://docs.google.com/document/d/1U1RGAehQwRypUTovF1KRlpiOFze0b-_2gc6fAH0KY0k/edit>
category: Development
abi: 5f9f78ecb3b750c146f729c77b7369a8
exposed: True
exposed-modules:
    SourceMap SourceMap.Types
hidden-modules: VLQ
import-dirs: /usr/lib/ghc-8.4.3/site-local/sourcemap-0.1.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/sourcemap-0.1.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/sourcemap-0.1.6
hs-libraries: HSsourcemap-0.1.6-51NpicaMDzE9fQzweNey22
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    aeson-1.4.1.0-Je86IRhAZ9i9fcEQGpo4BI
    unordered-containers-0.2.9.0-EtLPGprUM82GTPrcqDz1YE
    attoparsec-0.13.2.2-KZXutHSJyFFFErNezqs0Rb process-1.6.3.0
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8 text-1.2.3.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             aeson-1.4.1.0-Je86IRhAZ9i9fcEQGpo4BI=e763a4a7c222101a91911389c36d4497
             unordered-containers-0.2.9.0-EtLPGprUM82GTPrcqDz1YE=d999168fa5a35d048ce4f3e0442b4ae6
             attoparsec-0.13.2.2-KZXutHSJyFFFErNezqs0Rb=00fe5c2fcfc4c1dbb030be8823e7ce5f
             process-1.6.3.0=abb0cfe39ff8617a198f540a7db854a9
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=2191a818a7f61b012f58bd96949826c6
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
haddock-interfaces: /usr/share/doc/haskell-sourcemap/html/sourcemap.haddock
haddock-html: /usr/share/doc/haskell-sourcemap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sourcemap-0.1.6-97-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-sourcemap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: sourcemap
version: 0.1.6
id: sourcemap-0.1.6-BYu6oekMmwk7AZONAdkzie
key: sourcemap-0.1.6-BYu6oekMmwk7AZONAdkzie
license: BSD-3-Clause
copyright: 2012 Chris Done
maintainer: chrisdone@gmail.com
author: Chris Done
stability: alpha
synopsis: Implementation of source maps as proposed by Google and Mozilla.
description:
    Implementation of source maps, revision 3, proposed by Google and Mozilla here
    <https://wiki.mozilla.org/DevTools/Features/SourceMap> and here
    <https://docs.google.com/document/d/1U1RGAehQwRypUTovF1KRlpiOFze0b-_2gc6fAH0KY0k/edit>
category: Development
abi: cded4d6080ce50abbbcdba472088d822
exposed: True
exposed-modules:
    SourceMap SourceMap.Types
hidden-modules: VLQ
import-dirs: /usr/lib/ghc-8.6.1/site-local/sourcemap-0.1.6
library-dirs: /usr/lib/ghc-8.6.1/site-local/sourcemap-0.1.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/sourcemap-0.1.6
hs-libraries: HSsourcemap-0.1.6-BYu6oekMmwk7AZONAdkzie
depends:
    aeson-1.4.1.0-BaRGy5iBSXU37DPvV6hbuH
    attoparsec-0.13.2.2-FwHjzt71DhSHhjVAq259Rs base-4.12.0.0
    bytestring-0.10.8.2 process-1.6.3.0 text-1.2.3.1
    unordered-containers-0.2.9.0-8YwmaeVELNEGd3AzVghTJw
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-sourcemap/html/sourcemap.haddock
haddock-html: /usr/share/doc/haskell-sourcemap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
